import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { Label } from '../Label/index.js';
import { ChoiceGroupOption } from './ChoiceGroupOption/index.js';

const getClassNames = classNamesFunction();
let ChoiceGroupBase = class ChoiceGroupBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.selectedOption = {};
  }

  get classNames() {
    const {
      styles,
      theme,
      className
    } = this;
    return getClassNames(styles, {
      theme,
      className,
      optionsContainIconOrImage: false
    });
  }

  onClick(ev, option) {
    ev.preventDefault();
    if (option.disabled) return;
    this.selectedOption = option;
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      label,
      required,
      disabled,
      selectedOption,
      options
    } = this;
    return h("div", {
      "class": classNames.applicationRole
    }, [h("div", {
      "class": classNames.root
    }, [label && h(Label, {
      "class": classNames.label,
      "attrs": {
        "required": required,
        "disabled": disabled
      }
    }, [label]), h("div", {
      "class": classNames.flexContainer
    }, [options.map(option => {
      return h(ChoiceGroupOption, {
        "attrs": {
          "id": option.key,
          "checked": selectedOption.key === option.key
        },
        "key": option.key,
        "props": { ...option
        },
        "nativeOn": {
          "click": ev => this.onClick(ev, option)
        }
      }, [option.text]);
    })])])]);
  }

};

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ChoiceGroupBase.prototype, "label", void 0);

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], ChoiceGroupBase.prototype, "options", void 0);

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], ChoiceGroupBase.prototype, "value", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ChoiceGroupBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ChoiceGroupBase.prototype, "required", void 0);

ChoiceGroupBase = __decorate([Component({
  components: {
    ChoiceGroupOption,
    Label
  }
})], ChoiceGroupBase);

export { ChoiceGroupBase };
