import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import { Image } from '../../Image/index.js';
import { Icon } from '../../Icon/index.js';

const getClassNames = classNamesFunction();
let ChoiceGroupOptionBase = class ChoiceGroupOptionBase extends BaseComponent {
  get classNames() {
    const {
      styles,
      theme,
      iconProps,
      imageSrc,
      checked,
      disabled,
      imageSize,
      focused
    } = this;
    return getClassNames(styles, {
      theme: theme,
      hasIcon: !!iconProps,
      hasImage: !!imageSrc,
      checked,
      disabled,
      imageIsLarge: !!imageSrc && (imageSize.width > 71 || imageSize.height > 71),
      imageSize,
      focused
    });
  }

  render() {
    const h = arguments[0];
    const {
      id,
      classNames,
      text,
      imageSrc,
      imageAlt,
      imageSize,
      selectedImageSrc,
      iconProps,
      disabled
    } = this;
    return h("div", {
      "class": classNames.root
    }, [h("div", {
      "class": classNames.choiceFieldWrapper
    }, [h("input", {
      "attrs": {
        "id": `ChoiceGroup${this.uid}-${id}`,
        "name": `ChoiceGroup${this.uid}`,
        "disabled": this.disabled,
        "type": "radio"
      },
      "class": classNames.input
    }), h("label", {
      "attrs": {
        "for": `ChoiceGroup${this.uid}-${id}`
      },
      "class": classNames.field
    }, [imageSrc && h("div", {
      "class": classNames.innerField
    }, [h("div", {
      "class": classNames.imageWrapper
    }, [h(Image, {
      "attrs": {
        "src": imageSrc,
        "alt": imageAlt,
        "width": imageSize.width,
        "height": imageSize.height
      }
    })]), h("div", {
      "class": classNames.selectedImageWrapper
    }, [h(Image, {
      "attrs": {
        "src": selectedImageSrc,
        "alt": imageAlt,
        "width": imageSize.width,
        "height": imageSize.height
      }
    })])]), iconProps && h("div", {
      "class": classNames.innerField
    }, [h("div", {
      "class": classNames.iconWrapper
    }, [h(Icon, {
      "props": { ...iconProps
      }
    })])]), imageSrc || iconProps ? h("div", {
      "class": classNames.labelWrapper
    }, [h("span", {
      "class": "ms-ChoiceFieldLabel"
    }, [this.$slots.default || text])]) : h("span", {
      "class": "ms-ChoiceFieldLabel"
    }, [this.$slots.default || text])])])]);
  }

};

__decorate([Prop(), __metadata("design:type", String)], ChoiceGroupOptionBase.prototype, "id", void 0);

__decorate([Prop(), __metadata("design:type", String)], ChoiceGroupOptionBase.prototype, "text", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ChoiceGroupOptionBase.prototype, "iconProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ChoiceGroupOptionBase.prototype, "imageSrc", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ChoiceGroupOptionBase.prototype, "selectedImageSrc", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ChoiceGroupOptionBase.prototype, "imageAlt", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ChoiceGroupOptionBase.prototype, "checked", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ChoiceGroupOptionBase.prototype, "disabled", void 0);

__decorate([Prop({
  default: () => ({
    width: 32,
    height: 32
  })
}), __metadata("design:type", Object)], ChoiceGroupOptionBase.prototype, "imageSize", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ChoiceGroupOptionBase.prototype, "focused", void 0);

ChoiceGroupOptionBase = __decorate([Component], ChoiceGroupOptionBase);

export { ChoiceGroupOptionBase };
