import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { IconButton } from '../Button/IconButton/IconButton.js';
import { DialogType } from './DialogContent.types.js';

const getClassNames = classNamesFunction();
let DialogContentBase = class DialogContentBase extends BaseComponent {
  get classNames() {
    const {
      styles,
      theme,
      className,
      type,
      draggableHeaderClassName
    } = this;
    return getClassNames(styles, {
      theme: theme,
      className,
      isLargeHeader: type === DialogType.largeHeader,
      isClose: type === DialogType.close,
      draggableHeaderClassName
    });
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      css,
      title,
      type,
      showCloseButton,
      closeButtonAriaLabel,
      subText,
      subTextId
    } = this;
    const titleProps = this.titleProps || {};
    let subTextContent;

    if (subText) {
      subTextContent = h("p", {
        "class": classNames.subText,
        "attrs": {
          "id": subTextId
        }
      }, [subText]);
    }

    return h("div", {
      "class": classNames.content
    }, [h("div", {
      "class": classNames.header
    }, [h("div", _mergeJSXProps([{
      "attrs": {
        "id": titleProps.id,
        "role": "heading",
        "aria-level": 1
      }
    }, titleProps, {
      "class": css(classNames.title, titleProps.className)
    }]), [title]), h("div", {
      "class": classNames.topButton
    }, [(type === DialogType.close || showCloseButton && type !== DialogType.largeHeader) && h(IconButton, {
      "class": classNames.button,
      "attrs": {
        "iconProps": {
          iconName: 'Cancel'
        },
        "ariaLabel": closeButtonAriaLabel,
        "title": closeButtonAriaLabel
      },
      "on": {
        "click": ev => this.$emit('dismiss', ev)
      }
    })])]), h("div", {
      "class": classNames.inner
    }, [h("div", {
      "class": classNames.innerContent
    }, [subTextContent, this.$slots.default]), this.$slots.footer])]);
  }

};

__decorate([Prop({
  type: Number,
  default: DialogType.normal
}), __metadata("design:type", Number)], DialogContentBase.prototype, "type", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], DialogContentBase.prototype, "draggableHeaderClassName", void 0);

__decorate([Prop({
  type: Object,
  default: () => {}
}), __metadata("design:type", Object)], DialogContentBase.prototype, "titleProps", void 0);

__decorate([Prop({
  type: [String, Object],
  default: null
}), __metadata("design:type", Object)], DialogContentBase.prototype, "title", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DialogContentBase.prototype, "showCloseButton", void 0);

__decorate([Prop({
  type: String,
  default: 'Close'
}), __metadata("design:type", String)], DialogContentBase.prototype, "closeButtonAriaLabel", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], DialogContentBase.prototype, "subText", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], DialogContentBase.prototype, "subTextId", void 0);

DialogContentBase = __decorate([Component], DialogContentBase);

export { DialogContentBase };
