import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { getIconContent } from './FontIcon.js';
import { ImageLoadState } from '../Image/Image.types.js';

const getClassNames = classNamesFunction({
  // Icon is used a lot by other components.
  // It's likely to see expected cases which pass different className to the Icon.
  // Therefore setting a larger cache size.
  cacheSize: 100
});
let Icon = class Icon extends StatelessComponent {
  render(h, ctx) {
    const {
      className,
      iconName,
      theme,
      styles,
      imageErrorAs
    } = ctx.props;
    const isPlaceholder = typeof iconName === 'string' && iconName.length === 0;
    const isImage = !!ctx.props.imageProps;
    const iconContent = getIconContent(iconName) || {};
    const {
      iconClassName
    } = iconContent;
    const iconContentChildren = iconContent.children;
    const classNames = getClassNames(styles, {
      theme,
      className,
      iconClassName,
      isImage,
      isPlaceholder
    });
    const RootType = isImage ? 'span' : 'i';
    let imageLoadError = false;
    const imageProps = Object.assign(Object.assign({}, ctx.props.imageProps), {
      onLoadingStateChange: state => {
        if (ctx.props.imageProps && ctx.props.imageProps.onLoadingStateChange) {
          ctx.props.imageProps.onLoadingStateChange(state);
        }

        if (state === ImageLoadState.error) {
          imageLoadError = true;
        }
      }
    });
    const ImageType = imageLoadError && imageErrorAs || Image;
    const ariaLabel = ctx.data.attrs && (ctx.data.attrs['aria-label'] || ctx.data.attrs.ariaLabel);
    const containerProps = ariaLabel ? {
      'aria-label': ariaLabel
    } : {
      'aria-hidden': !(ctx.props['aria-labelledby'] || imageProps['aria-labelledby'])
    };
    return h(RootType, _mergeJSXProps([{
      "attrs": {
        "data-icon-name": iconName
      }
    }, Object.assign(Object.assign({}, ctx.data), {
      props: containerProps
    }), {
      "class": classNames.root
    }]), [isImage // @ts-ignore
    ? h(ImageType, {
      "props": { ...imageProps
      }
    }) : ctx.scopedSlots.default && ctx.scopedSlots.default({}) || (typeof iconContentChildren === 'function' ? iconContentChildren(h) : iconContentChildren)]);
  }

};

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], Icon.prototype, "iconName", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], Icon.prototype, "imageProps", void 0);

__decorate([Prop({
  type: [String, Object],
  default: null
}), __metadata("design:type", Object)], Icon.prototype, "imageErrorAs", void 0);

Icon = __decorate([Component], Icon);
var Icon$1 = Icon;

export default Icon$1;
