import { __decorate, __metadata } from 'tslib';
import { Model, Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { Label } from '../Label/index.js';

const getClassNames = classNamesFunction();
let ToggleBase = class ToggleBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.internalChecked = this.defaultChecked || this.checked;
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      internalChecked,
      disabled,
      label,
      onText,
      offText
    } = this;
    return h("div", {
      "class": classNames.root
    }, [this.$scopedSlots.label ? this.$scopedSlots.label({
      checked: internalChecked,
      disabled,
      label
    }) : h(Label, {
      "class": classNames.label,
      "attrs": {
        "for": `Toggle${this.uid}`
      }
    }, [label]), h("div", {
      "class": classNames.container
    }, [h("button", {
      "attrs": {
        "id": `Toggle${this.uid}`
      },
      "ref": "toggleButton",
      "class": classNames.pill,
      "on": {
        "click": this.onClick
      }
    }, [h("div", {
      "class": classNames.thumb
    })]), (internalChecked && onText || !internalChecked && offText) && h(Label, {
      "class": classNames.text,
      "attrs": {
        "for": `Toggle${this.uid}`
      }
    }, [internalChecked ? onText : offText])])]);
  }

  get classNames() {
    const {
      theme,
      className,
      disabled,
      internalChecked,
      inlineLabel,
      onText,
      offText
    } = this;
    return getClassNames(this.styles, {
      theme: theme,
      className: className,
      disabled: disabled,
      checked: internalChecked,
      inlineLabel: inlineLabel,
      onOffMissing: !onText && !offText
    });
  }

  focus() {
    this.$refs.toggleButton.focus();
  }

  onCheckedChanged(checked, prevVal) {
    this.$emit('input', checked);
  }

  onClick() {
    if (this.disabled) return;
    this.internalChecked = !this.internalChecked;
  }

};

__decorate([Model('input', {
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ToggleBase.prototype, "checked", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ToggleBase.prototype, "label", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ToggleBase.prototype, "defaultChecked", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ToggleBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ToggleBase.prototype, "inlineLabel", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ToggleBase.prototype, "onText", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], ToggleBase.prototype, "offText", void 0);

__decorate([Watch('internalChecked'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], ToggleBase.prototype, "onCheckedChanged", null);

ToggleBase = __decorate([Component], ToggleBase);

export { ToggleBase };
