import * as Components from '../components';
import { createTheme, loadTheme as baseLoadTheme } from '@uifabric/styling';
import { registerCSSVars } from './registerCSSVars';
import { toKebabCase } from '../utilities';
export function loadTheme(theme, useCSSVars = false) {
    const _theme = createTheme(theme);
    if (useCSSVars) {
        let { palette, semanticColors } = _theme;
        // generate new css vars
        palette = registerCSSVars('palette', palette);
        semanticColors = registerCSSVars('semanticColors', semanticColors);
        // update theme
        baseLoadTheme({
            palette,
            semanticColors,
        });
    }
    return _theme;
}
export default function install(Vue, options = {}, theme = {}) {
    for (const componentName in Components) {
        const Component = Components[componentName];
        if (Component && Component.prototype instanceof Vue) {
            const name = `${options.prefix || 'f'}-${toKebabCase(componentName)}`;
            Vue.component(name, Component);
        }
    }
    loadTheme(theme, options.useCSSVars);
}
/*

============================
    CSS Vars
--neutralLight: #eaeaea;
--bodyFrameBackground: var(--neutralLight)

{
  neutralLight: 'var(--neutralLight)'
}
{
  bodyFrameBackground: 'var(--neutralLight)'
}

======================================
    No CSS Vars
{
  neutralLight: '#eaeaea'
}
{
  bodyFrameBackground: '#eaeaea'
}

 */
//# sourceMappingURL=office-fabric.js.map